@@ -20,16 +20,17 @@ Includes decorator for re-raising Zun-type exceptions.
 
 import functools
 import inspect
-from oslo_utils import uuidutils
+import re
 import sys
-from webob import util as woutil
 
 from keystoneclient import exceptions as keystone_exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
+from oslo_utils import uuidutils
 import pecan
 import six
+from webob import util as woutil
 
 from zun.common.i18n import _
 import zun.conf
@@ -44,7 +45,7 @@ try:
 except cfg.NoSuchOptError as e:
     # Note:work around for zun run against master branch
     # in devstack gate job, as zun not branched yet
-    # verisonobjects kilo/master different version can
+    # versionobjects kilo/master different version can
     # cause issue here. As it changed import group. So
     # add here before branch to prevent gate failure.
     # Bug: #1447873
@@ -96,11 +97,11 @@ def wrap_controller_exception(func, func_server_error, func_client_error):
     """This decorator wraps controllers methods to handle exceptions:
 
     - if an unhandled Exception or a ZunException with an error code >=500
-    is catched, raise a http 5xx ClientSideError and correlates it with a log
-    message
+      is catched, raise a http 5xx ClientSideError and correlates it with a log
+      message
 
     - if a ZunException is catched and its error code is <500, raise a http
-    4xx and logs the excp in debug mode
+      4xx and logs the excp in debug mode
 
     """
     @functools.wraps(func)
@@ -129,11 +130,19 @@ def wrap_controller_exception(func, func_server_error, func_client_error):
     return wrapped
 
 
+def convert_excp_to_err_code(excp_name):
+    """Convert Exception class name (CamelCase) to error-code (Snake-case)"""
+    words = re.findall(r'[A-Z]?[a-z]+|[A-Z]{2,}(?=[A-Z][a-z]|\d|\W|$)|\d+',
+                       excp_name)
+    return '-'.join([str.lower(word) for word in words])
+
+
 def wrap_pecan_controller_exception(func):
     """This decorator wraps pecan controllers to handle exceptions."""
     def _func_server_error(log_correlation_id, status_code):
         pecan.response.status = status_code
         return {
+            'faultcode': 'Server',
             'status_code': status_code,
             'title': woutil.status_reasons[status_code],
             'description': six.text_type(OBFUSCATED_MSG % log_correlation_id),
@@ -142,6 +151,8 @@ def wrap_pecan_controller_exception(func):
     def _func_client_error(excp, status_code):
         pecan.response.status = status_code
         return {
+            'faultcode': 'Client',
+            'faultstring': convert_excp_to_err_code(excp.__class__.__name__),
             'status_code': status_code,
             'title': six.text_type(excp),
             'description': six.text_type(excp),
@@ -190,7 +201,7 @@ class ZunException(Exception):
             self.message = message
 
         try:
-            self.message = self.message % kwargs
+            self.message = str(self.message) % kwargs
         except KeyError:
             # kwargs doesn't match a variable in the message
             # log the issue and the kwargs
@@ -228,6 +239,10 @@ class ObjectNotUnique(ZunException):
     message = _("The %(name)s already exists.")
 
 
+class ObjectActionError(ZunException):
+    message = _('Object action %(action)s failed because: %(reason)s')
+
+
 class ResourceNotFound(ObjectNotFound):
     message = _("The %(name)s resource %(id)s could not be found.")
     code = 404
@@ -309,6 +324,10 @@ class Conflict(ZunException):
     code = 409
 
 
+class ConflictOptions(Conflict):
+    message = _('Conflicting options.')
+
+
 class InvalidState(Conflict):
     message = _("Invalid resource state.")
 
@@ -319,8 +338,19 @@ class InvalidParameterValue(Invalid):
     message = _("%(err)s")
 
 
-class InvalidParam(Invalid):
-    message = _('Invalid param %(param)s')
+class InvalidParamInVersion(Invalid):
+    message = _('Invalid param %(param)s because current request '
+                'version is %(req_version)s. %(param)s is only '
+                'supported from version %(min_version)s')
+
+
+class InvalidQuotaValue(Invalid):
+    message = _("Change would make usage less than 0 for the following "
+                "resources: %(unders)s")
+
+
+class InvalidQuotaMethodUsage(Invalid):
+    message = _("Wrong quota method %(method)s used on resource %(res)s")
 
 
 class PatchError(Invalid):
@@ -352,22 +382,47 @@ class ComputeNodeNotFound(HTTPNotFound):
     message = _("Compute node %(compute_node)s could not be found.")
 
 
+class NetworkNotFound(HTTPNotFound):
+    message = _("Neutron network %(network)s could not be found.")
+
+
+class RegistryNotFound(HTTPNotFound):
+    message = _("Registry %(registry)s could not be found.")
+
+
+class NetworkAlreadyExists(ResourceExists):
+    message = _("A network with %(field)s %(value)s already exists.")
+
+    def __init__(self, field, value):
+        self.field = field
+        self.value = value
+        super(NetworkAlreadyExists, self).__init__(field=field, value=value)
+
+
 class PortNotFound(HTTPNotFound):
     message = _("Neutron port %(port)s could not be found.")
 
 
-class ImageNotFound(HTTPNotFound):
+class VolumeMappingNotFound(HTTPNotFound):
+    message = _("Volume mapping %(volume_mapping)s could not be found.")
+
+
+class VolumeNotFound(HTTPNotFound):
+    message = _("Volume %(volume)s could not be found.")
+
+
+class ImageNotFound(Invalid):
     message = _("Image %(image)s could not be found.")
 
 
+class OperationNotSupported(ZunException):
+    message = _("The operation is not supported.")
+
+
 class ZunServiceNotFound(HTTPNotFound):
     message = _("Zun service %(binary)s on host %(host)s could not be found.")
 
 
-class ResourceProviderNotFound(HTTPNotFound):
-    message = _("Resource provider %(resource_provider)s could not be found.")
-
-
 class ResourceClassNotFound(HTTPNotFound):
     message = _("Resource class %(resource_class)s could not be found.")
 
@@ -384,6 +439,11 @@ class ContainerAlreadyExists(ResourceExists):
     message = _("A container with %(field)s %(value)s already exists.")
 
 
+class ExecInstanceAlreadyExists(ResourceExists):
+    message = _("An exec instance with exec_id %(exec_id)s already exists "
+                "in container.")
+
+
 class ComputeNodeAlreadyExists(ResourceExists):
     message = _("A compute node with %(field)s %(value)s already exists.")
 
@@ -404,6 +464,18 @@ class ResourceClassAlreadyExists(ResourceExists):
     message = _("A resource class with %(field)s %(value)s already exists.")
 
 
+class VolumeMappingAlreadyExists(ResourceExists):
+    message = _("A volume mapping with %(field)s %(value)s already exists.")
+
+
+class VolumeAlreadyExists(ResourceExists):
+    message = _("A volume with %(field)s %(value)s already exists.")
+
+
+class RegistryAlreadyExists(ResourceExists):
+    message = _("A registry with %(field)s %(value)s already exists.")
+
+
 class PortNotUsable(Invalid):
     message = _("Port %(port)s not usable for the container.")
 
@@ -412,6 +484,14 @@ class PortInUse(Invalid):
     message = _("Port %(port)s is still in use.")
 
 
+class VolumeNotUsable(Invalid):
+    message = _("Volume %(volume)s not usable for the container.")
+
+
+class VolumeInUse(Invalid):
+    message = _("Volume %(volume)s is still in use.")
+
+
 class PortBindingFailed(Invalid):
     message = _("Binding failed for port %(port)s, please check neutron "
                 "logs for more information.")
@@ -449,7 +529,7 @@ class EntityNotFound(ZunException):
 
 
 class CommandError(ZunException):
-    message = _("The command: %(cmd)s failed on the system.")
+    message = _("The command: %(cmd)s failed on the system, due to %(error)s")
 
 
 class NoValidHost(ZunException):
@@ -514,14 +594,26 @@ class InvalidWebsocketToken(ZunException):
     message = _("Websocket token is invalid")
 
 
-class ValidationError(ZunException):
-    message = _("Validation error")
-
-
 class ResourcesUnavailable(ZunException):
     message = _("Insufficient compute resources: %(reason)s.")
 
 
+class MakeFileSystemException(ZunException):
+    message = _("Unexpected error while make file system")
+
+
+class MountException(ZunException):
+    message = _("Unexpected error while mount device")
+
+
+class UnmountException(ZunException):
+    message = _("Unexpected error while do umount")
+
+
+class FileNotFound(ZunException):
+    message = _("The expected file not exist")
+
+
 class PciConfigInvalidWhitelist(ZunException):
     message = _("Invalid PCI devices Whitelist config %(reason)s")
 
@@ -544,6 +636,12 @@ class PciDeviceNotFound(NotFound):
     message = _("PCI Device %(node_id)s:%(address)s not found.")
 
 
+class PciDevicePoolEmpty(ZunException):
+    message = _(
+        "Attempt to consume PCI device %(compute_node_uuid)s:%(address)s "
+        "from empty pool")
+
+
 class CapsuleAlreadyExists(ResourceExists):
     message = _("A capsule with %(field)s %(value)s already exists.")
 
@@ -554,3 +652,238 @@ class CapsuleNotFound(HTTPNotFound):
 
 class InvalidCapsuleTemplate(ZunException):
     message = _("Invalid capsule template: %(reason)s.")
+
+
+class FailedParseStringToJson(ZunException):
+    message = _("Failed parse string to json: %(reason)s.")
+
+
+class ExternalNetworkAttachForbidden(NotAuthorized):
+    message = _("It is not allowed to create an interface on "
+                "external network %(network_uuid)s")
+
+
+class PciDeviceInvalidStatus(Invalid):
+    message = _(
+        "PCI device %(compute_node_id)s:%(address)s is %(status)s "
+        "instead of %(hopestatus)s")
+
+
+class PciDeviceVFInvalidStatus(Invalid):
+    message = _(
+        "Not all Virtual Functions of PF %(compute_node_id)s:%(address)s "
+        "are free.")
+
+
+class PciDevicePFInvalidStatus(Invalid):
+    message = _(
+        "Physical Function %(compute_node_id)s:%(address)s, related to VF"
+        " %(compute_node_id)s:%(vf_address)s is %(status)s "
+        "instead of %(hopestatus)s")
+
+
+class PciDeviceInvalidOwner(Invalid):
+    message = _(
+        "PCI device %(compute_node_id)s:%(address)s is owned by %(owner)s "
+        "instead of %(hopeowner)s")
+
+
+class VolumeCreateFailed(Invalid):
+    message = _("Volume Creation failed: %(creation_failed)s")
+
+
+class VolumeDeleteFailed(Invalid):
+    message = _("Volume Deletion failed: %(deletion_failed)s")
+
+
+class SecurityGroupCannotBeApplied(Invalid):
+    message = _("Security groups cannot apply to the container.")
+
+
+class SecurityGroupCannotBeRemoved(Invalid):
+    message = _("Security groups cannot be removed from the container.")
+
+
+class ContainerActionNotFound(ZunException):
+    message = _("Action for request_id %(request_id)s on container"
+                " %(container_uuid)s not fount")
+
+
+class ContainerActionEventNotFound(ZunException):
+    message = _("Event %(event)s not found for action id %(action_id)s")
+
+
+class OverQuota(ZunException):
+    message = _("Quota exceeded for resources: %(overs)s")
+    code = 403
+
+
+class QuotaNotFound(NotFound):
+    message = _("Quota could not be found.")
+
+
+class QuotaUsageNotFound(NotFound):
+    message = _("Quota usage could not be found")
+
+
+class ProjectQuotaNotFound(QuotaNotFound):
+    message = _("Quota for project %(project_id)s could not be found.")
+
+
+class QuotaAlreadyExists(ZunException):
+    message = _("Quota already exists for project %(project_id)s, "
+                "resource %(resource)s.")
+
+
+class QuotaClassNotFound(QuotaNotFound):
+    message = _("Quota class %(class_name)s could not be found.")
+
+
+class QuotaResourceUnknown(QuotaNotFound):
+    message = _("Unknow quota resources %(unknown)s.")
+
+
+class Base64Exception(Invalid):
+    message = _("Invalid Base 64 file data")
+
+
+class InvalidEncryptionKey(ZunException):
+    message = _('Can not decrypt data with the auth_encryption_key '
+                'in zun config.')
+
+
+class InvalidReference(ZunException):
+    message = _('invalid reference')
+
+
+class ReferenceInvalidFormat(InvalidReference):
+    message = _('invalid reference format')
+
+
+class NameEmpty(InvalidReference):
+    message = _('repository name must have at least one component')
+
+
+class NameTooLong(InvalidReference):
+    message = _('repository name must not be more than %(length_max)s '
+                'characters')
+
+
+# An exception with this name is used on both sides of the placement/zun
+# interaction.
+class ResourceProviderInUse(ZunException):
+    message = _("Resource provider has allocations.")
+
+
+class ResourceProviderRetrievalFailed(ZunException):
+    message = _("Failed to get resource provider with UUID %(uuid)s")
+
+
+class ResourceProviderAggregateRetrievalFailed(ZunException):
+    message = _("Failed to get aggregates for resource provider with UUID"
+                " %(uuid)s")
+
+
+class ResourceProviderTraitRetrievalFailed(ZunException):
+    message = _("Failed to get traits for resource provider with UUID"
+                " %(uuid)s")
+
+
+class ResourceProviderCreationFailed(ZunException):
+    message = _("Failed to create resource provider %(name)s")
+
+
+class ResourceProviderDeletionFailed(ZunException):
+    message = _("Failed to delete resource provider %(uuid)s")
+
+
+class ResourceProviderUpdateFailed(ZunException):
+    message = _("Failed to update resource provider via URL %(url)s: "
+                "%(error)s")
+
+
+class ResourceProviderNotFound(NotFound):
+    message = _("No such resource provider %(name_or_uuid)s.")
+
+
+class ResourceProviderSyncFailed(ZunException):
+    message = _("Failed to synchronize the placement service with resource "
+                "provider information supplied by the compute host.")
+
+
+class PlacementAPIConnectFailure(ZunException):
+    message = _("Unable to communicate with the Placement API.")
+
+
+class PlacementAPIConflict(ZunException):
+    """Any 409 error from placement APIs should use (a subclass of) this
+    exception.
+    """
+    message = _("A conflict was encountered attempting to invoke the "
+                "placement API at URL %(url)s: %(error)s")
+
+
+class ResourceProviderUpdateConflict(PlacementAPIConflict):
+    """A 409 caused by generation mismatch from attempting to update an
+    existing provider record or its associated data (aggregates, traits, etc.).
+    """
+    message = _("A conflict was encountered attempting to update resource "
+                "provider %(uuid)s (generation %(generation)d): %(error)s")
+
+
+class InvalidResourceClass(Invalid):
+    message = _("Resource class '%(resource_class)s' invalid.")
+
+
+class InvalidResourceAmount(Invalid):
+    message = _("Resource amounts must be integers. Received '%(amount)s'.")
+
+
+class InvalidInventory(Invalid):
+    message = _("Inventory for '%(resource_class)s' on "
+                "resource provider '%(resource_provider)s' invalid.")
+
+
+# An exception with this name is used on both sides of the placement/
+# nova interaction.
+class InventoryInUse(InvalidInventory):
+    pass
+
+
+class UsagesRetrievalFailed(ZunException):
+    message = _("Failed to retrieve usages for project '%(project_id)s' and "
+                "user '%(user_id)s'.")
+
+
+class AllocationUpdateFailed(ZunException):
+    message = _('Failed to update allocations for consumer %(consumer_uuid)s. '
+                'Error: %(error)s')
+
+
+class ConsumerAllocationRetrievalFailed(ZunException):
+    message = _("Failed to retrieve allocations for consumer "
+                "%(consumer_uuid)s: %(error)s")
+
+
+class TraitRetrievalFailed(ZunException):
+    message = _("Failed to get traits for resource provider with UUID"
+                " %(uuid)s")
+
+
+class TraitCreationFailed(ZunException):
+    message = _("Failed to create trait %(name)s: %(error)s")
+
+
+class AllocationMoveFailed(ZunException):
+    message = _('Failed to move allocations from consumer %(source_consumer)s '
+                'to consumer %(target_consumer)s. '
+                'Error: %(error)s')
+
+
+class ResourceProviderAllocationRetrievalFailed(ZunException):
+    message = _("Failed to retrieve allocations for resource provider "
+                "%(rp_uuid)s: %(error)s")
+
+
+class ComputeHostNotFound(NotFound):
+    message = _("Compute host %(host)s could not be found.")
