@@ -178,7 +178,7 @@ class TestImageController(api_base.FunctionalTest):
         response = self.get('/v1/images/redis/search/')
         self.assertEqual(200, response.status_int)
         mock_image_search.assert_called_once_with(
-            mock.ANY, 'redis', CONF.default_image_driver, False)
+            mock.ANY, 'redis', CONF.default_image_driver, False, None)
 
     @patch('zun.compute.api.API.image_search')
     def test_search_image_with_tag(self, mock_image_search):
@@ -186,14 +186,14 @@ class TestImageController(api_base.FunctionalTest):
         response = self.get('/v1/images/redis:test/search/')
         self.assertEqual(200, response.status_int)
         mock_image_search.assert_called_once_with(
-            mock.ANY, 'redis:test', CONF.default_image_driver, False)
+            mock.ANY, 'redis:test', CONF.default_image_driver, False, None)
 
     @patch('zun.compute.api.API.image_search')
     def test_search_image_not_found(self, mock_image_search):
         mock_image_search.side_effect = exception.ImageNotFound
         self.assertRaises(AppError, self.get, '/v1/images/redis/search/')
         mock_image_search.assert_called_once_with(
-            mock.ANY, 'redis', CONF.default_image_driver, False)
+            mock.ANY, 'redis', CONF.default_image_driver, False, None)
 
     @patch('zun.compute.rpcapi.API.image_search')
     def test_search_image_with_exact_match_true(self, mock_image_search):
@@ -202,7 +202,7 @@ class TestImageController(api_base.FunctionalTest):
             '/v1/images/redis/search?exact_match=true&image_driver=docker')
         self.assertEqual(200, response.status_int)
         mock_image_search.assert_called_once_with(
-            mock.ANY, 'redis', 'docker', True)
+            mock.ANY, 'redis', 'docker', True, None)
 
     @patch('zun.compute.rpcapi.API.image_search')
     def test_search_image_with_exact_match_false(self, mock_image_search):
@@ -211,7 +211,7 @@ class TestImageController(api_base.FunctionalTest):
             '/v1/images/redis/search?exact_match=false&image_driver=glance')
         self.assertEqual(200, response.status_int)
         mock_image_search.assert_called_once_with(
-            mock.ANY, 'redis', 'glance', False)
+            mock.ANY, 'redis', 'glance', False, None)
 
     @patch('zun.compute.api.API.image_search')
     def test_search_image_with_exact_match_wrong(self, mock_image_search):
