@@ -344,28 +344,34 @@ class TestObject(test_base.TestCase, _TestObject):
 # For more information on object version testing, read
 # https://docs.openstack.org/zun/latest/
 object_data = {
-    'Container': '1.36-ad2bacdaa51afd0047e96003f93ff181',
-    'VolumeMapping': '1.2-2230102beda09cf5caabd130c600dc92',
-    'Image': '1.1-330e6205c80b99b59717e1cfc6a79935',
+    'Capsule': '1.1-829f8acb1ca4b57d33fa09233c9520d3',
+    'CapsuleContainer': '1.1-712817e2fcc085dbf0a794b3770e1907',
+    'CapsuleInitContainer': '1.1-712817e2fcc085dbf0a794b3770e1907',
+    'Container': '1.40-a24b78bcfb8c2c7e77ed24bd4a43dda1',
+    'Cpuset': '1.0-06c4e6335683c18b87e2e54080f8c341',
+    'Volume': '1.0-034768f2f5c5e89acb5ee45c6d3f3403',
+    'VolumeMapping': '1.5-57febc66526185a75a744637e7a387c7',
+    'Image': '1.2-80504fdd797e9dd86128a91680e876ad',
     'MyObj': '1.0-34c4b1aadefd177b13f9a2f894cc23cd',
-    'NUMANode': '1.0-cba878b70b2f8b52f1e031b41ac13b4e',
+    'NUMANode': '1.0-6da86e2dd7f28253e2b9ac60c002ea8f',
     'NUMATopology': '1.0-b54086eda7e4b2e6145ecb6ee2c925ab',
     'ResourceClass': '1.1-d661c7675b3cd5b8c3618b68ba64324e',
     'ResourceProvider': '1.0-92b427359d5a4cf9ec6c72cbe630ee24',
     'ZunService': '1.2-deff2a74a9ce23baa231ae12f39a6189',
-    'Capsule': '1.6-7238a80b4ef34e219c135fa72d0adc06',
     'PciDevice': '1.1-6e3f0851ad1cf12583e6af4df1883979',
-    'ComputeNode': '1.12-12d7c4fdeb26d58e1988d8577c838512',
+    'ComputeNode': '1.14-5cf09346721129068d1f72482309276f',
     'PciDevicePool': '1.0-3f5ddc3ff7bfa14da7f6c7e9904cc000',
     'PciDevicePoolList': '1.0-15ecf022a68ddbb8c2a6739cfc9f8f5e',
-    'Quota': '1.2-3a7d520d119fe1e886baad968ef7990a',
-    'QuotaClass': '1.1-239ae335b32036b86504684d3fdbeb7f',
+    'Quota': '1.3-fcaaaf4b6e983207edba27a1cf8e51ab',
+    'QuotaClass': '1.2-4739583a70891fbc145031228fb8001e',
     'ContainerPCIRequest': '1.0-b060f9f9f734bedde79a71a4d3112ee0',
     'ContainerPCIRequests': '1.0-7b8f7f044661fe4e24e6949c035af2c4',
-    'ContainerAction': '1.1-b0c721f9e10c6c0d1e41e512c49eb877',
+    'ContainerAction': '1.2-4ae05fe3d1576c211c2425e4db190ef2',
     'ContainerActionEvent': '1.0-2974d0a6f5d4821fd4e223a88c10181a',
-    'Network': '1.0-235ba13359282107f27c251af9aaffcd',
+    'Network': '1.1-26e8d37a54e5fc905ede657744a221d9',
     'ExecInstance': '1.0-59464e7b96db847c0abb1e96d3cec30a',
+    'Registry': '1.0-36c2053fbc30e0021630e657dd1699c9',
+    'RequestGroup': '1.0-5e08d68d0a63b729778340d608ec4eae',
 }
 
 
